bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 25. Aventiure
___________________________________________________ #### Aventivre wie die herren alle #### zen hevnen fvren
###### 1506 | ### Nv laze wir beliben | wi si gefvren hie ### hochgemvte recken | di gefvrn nie ### so rehte herliche | in deheines chveniges lant ### si heten swaz si wolden | beidiv waffen vnt gewant
###### 1507 | ### der vogt von dem rine | chleidete sine man ### sehzech vnd tvsent | als ich vernomen han ### vnd niwen tvsent chnehte | gegen der hohgezit ### di si da heime liezen | di beweinetenz sit
###### 1508 | ### do trvch man div gereite | ce wormez veber den hoff ### do sprach da von spyre | ein alter bisschoff ### zv der schoenen vten | vnser frivnde wellent varn ### gegen der hohgezite | got mvez ir ere da bewarn
###### 1509 | ### do sprach zv zir chinden | div edel vte ### ir soldet hie beliben | helde gvte ### mir ist getrovmet hinte | von angestlicher not ### wi allez diz gefvegele | in disem lande waere tot
###### 1510 | ### swer sich an trovme wendet | sprach do hagene ### der en weiz der rehten maere | niht ce sagene ### wenn ez im ze eren | vollechlichen ste ### ich wil daz min herre | ze hove nach vrlovbe ge
###### 1511 | ### wir svln gerne riten | in ecelen lant ### da mach wol dienen chvenegen | gvter held hant ### da wir da schowen mvezen | criemhilde hohgezit ### hagen riet di reise | iedoch gerov ez in sit
###### 1512 | ### er hetez widerraten | want daz gernot ### mit vngefvegen worten | im also missebot ### er mant in sifrides | vrovn criemhilden man ### er sprach davon wil hagene | di grozen hovereise lan
###### 1513 | ### do sprach von tronege hagene | dvrh vorhte ich nine tvo ### swenne ir gebietet helde | so svlt ir griffen zvo ### ia rit ich mit iv gerne | in ecelen lant ### sit wart von im verhowen | vil manich helm vnde rant
###### 1514 | ### div siff bereitet waren | da was vil manech man ### swaz si chleider heten | div trvch man dar an ### si warn vmmvezech | vor abendens zit ### si hvoben sich von hvse | vil harte vroeliche sit
###### 1515 | ### gezelt vnde hvetten | spien man an daz gras ### anderthalp des rines | do daz geschehen was ### der kvenech bat noch beliben | daz sin vil schoene wip ### si trvote noch des nahtes | den sinen waetlichen lip
###### 1516 | ### pvsvnen floytiern | hvp sich des morgens frv ### dar si varn solden | da bereiten si sich zv ### swer liep heten arme | der trvote frivndes lip ### des schet sit vil mit leide | des kvnech ecelen wip
###### 1517 | ### div chint der schoenen vten | di heten einen man ### chvene vnd getriwe | do si wolden dan ### do sagt er dem kvenege | tovgen sinen mvt ### er sprach des mvoz ich trvren | daz ir di hovereise tvt
###### 1518 | ### er was geheizen rvmolt | vnd was ein helt cer hant ### er sprach wem welt ir lazen | livte vnd ovch div lant ### daz niemen chan erwenden | iv recken iwern mvt ### div criemhilden maere | nie gedvhten mich gvt
###### 1519 | ### daz lant si dir bevolhen | vnt min kindelin ### vnt diene wol den vrowen | daz ist der wille min ### swen dv sehest weinen | dem troeste sinen lip ### ia ne getvt vns nimmer | des kvenech eceln wip
###### 1520 | ### div ross bereitet waren | den kvenegen vnd ir man ### mit minnechlichem chvessen | schiet vil maniger dan ### dem in hohem mvte | lebte da der lip ### daz mvose sit beweinen | vil manich waetlichez wip
###### 1521 | ### do man di snellen recken | cen rossen sah gan ### do chos man vil der vrowen | trvrechlichen stan ### daz ir vil langenz scheiden | sagt in vil wol ir mvt ### vf grozen schaden ce chomene | daz herce niemen sanfte tvt
###### 1522 | ### di snellen bvergonden | sich vz hvoben ### do wart in dem lande | ein miche voben ### beidenthalp der berge | weinte wip vnd man ### swi dort ir volch getaete | si fvren vroeliche dan
###### 1523 | ### di nibelvnges helde | chomen mit in dan ### in tvsent halspergen | ce hvs si heten lan ### vil manige schoene vrowen | di gesahen si nimmer me ### di sifrides wunden | taten criemhilde we
###### 1524 | ### do sicheten si ir reise | gegen dem mevne dan ### vf dvrch ostervranchen | di gventheres man ### dar leite si do hagene | dem was ez wol bechant ### ir marschalk was danchwart | der helt von bvergonden lant
###### 1525 | ### do si von ostervranchen | gegen salvelde ritten ### do mohte man si chiesen | an herlichen siten ### di fversten vnt ir mage | di helde lobesam ### an dem zwelften morgen | der kvenich an di tvnowe quam
###### 1526 | ### do reit von tronege hagen | zaller vorderost ### er was den nibelvngen | ein helflicher trost ### do derbeizte der degen chvene | nider vf den sant ### sin ross er harte balde | zv zeinem bovme gebant
###### 1527 | ### daz wazzer was engozen | div sciff verborgen ### ez ergie den nibelvngen | ze grozen sorgen ### wi si chomen vebere | der wach was in ze breit ### do erbeizte zv der erden | vil manich ritter gemeit
###### 1528 | ### leide sprach do hagene | mach dir wol hi geschehen ### voget von dem rine | nv maht dv selbe sehen ### daz wazer ist engozen | vil starch ist im sin flvot ### ia waene wir verliesen | noch hivte hie manigen helt gvt
###### 1529 | ### waz wizet ir mir hagene | sprach der kvenech her ### dvrh iwer selbes tvgende | vntroestet vns niht mer ### den fvrt svlt ir vns svchen | hinveber an daz lant ### daz wir von hinnen bringen | beidiv ross vnt ovch gewant
###### 1530 | ### ian ist mir sprach hagene | min leben niht so leit ### daz ich mich welle ertrenchen | in disen venden breit ### e sol von minen handen | ersterben manich man ### in ecelen landen | des ich vil gvten willen han
###### 1531 | ### belibet bi dem wazer | ir stolzen ritter gvt ### ich wil di vergen svchen | selbe bi der flvot ### di vns bringen vebere | in gelfrates lant ### do nam der starche hagene | sinen gvten schildes rant
###### 1532 | ### er was vil wol gewaffent | den schilt er dannen trvch ### sinen helm vf gebvnden | lieht was er genvch ### do trvg er ob der brvenne | ein waffen also breit ### daz ce beden eken | harte vreislichen sneit
###### 1533 | ### do svcht er nah den vergen | wider vnd dan ### er horte wazer giezen | losen er began ### in einem schoenem brvnnen | daz taten wisiv wip ### di wolden sih da chvelen | vnd badeten ir lip
###### 1534 | ### hagen wart innen | er sleich in tovgen nach ### do si daz versvnnen | do wart in dannen gach ### daz si im entrvnnen | des waren si vil her ### er nam in ir gewaete | der helt en schadete in niht mer
###### 1535 | ### do sprach daz eine merewib | hadebvrch was si genant ### edel ritter hagene | wir tvon iv hie bechant ### swenne ir vns degen chvene | gebet wider vnser wat ### wi iv ze den hivnen | disiv hovereise ergat
###### 1536 | ### si swebten sam di vogele | vor im vf der flvt ### des dvhten in ir sinne | starch vnd gvt ### swaz si im sagen wolden | er gelovbtez deste baz ### des er do hin zin gerte | vil wol bescheideten si im daz
###### 1537 | ### si sprach ir mvegt wol riten | in eceln lant ### des setze ich iv ce bvergen | mine triwe hi ce hant ### daz helde nie gefvoren | in deheiniv riche baz ### nach also grozen eren | nv gelovbet waerliche daz
###### 1538 | ### der rede was do hagene | in sinem hercen her ### do gap er in ir chleider | vnd svmte sich niht mer ### do si do angeliten | ir wunderlich gewant ### do sagten si im rehte | di reise in ecelen lant
###### 1539 | ### do sprach daz ander merewip | div hiez sigelint ### ich wil dich warnen hagen | daz aldrianes chint ### dvrh der waete liebe | hat min mvome dir gelogen ### chvemestv hin cen hivnen | so bistv sere betrogen
###### 1540 | ### ia soltv cheren widere | daz ist dir an der zit ### wand ir helde chvene | also geladet sit ### daz ir sterben mvezet | in eceln lant ### swelhe dar geritent | di habent den tot an der hant
###### 1541 | ### do sprach aber hagene | ir trieget ane not ### wi moehtez sich gefvegen | daz wir alle tot ### solden da beliben | dvrh iemens haz ### si begonden im div maere | sagen chventlicher baz
###### 1542 | ### do sprach aber div eine | ez mvz also wesen ### daz iwer deheiner | chan da niht genesen ### niwan des chveneges kappelan | daz ist vns wol bechant ### der chvemet gesvnt widere | in daz gventheres lant
###### 1543 | ### do sprach in grimmem mvote | der chvene hagene ### daz waere minen herren | mvelich ce sagene ### daz wir alle cen hivnen | solden vliesen den lip ### noch zeige vns vberz wazer | daz allerwiseste wip
###### 1544 | ### si sprach sit dv der verte | niht welles haben rat ### swa obene bi dem wazer | ein herberge stat ### da inne ist ein verge | vnd niender anderswa ### der maere der er vragte | der gelovbet er sich da
###### 1545 | ### dem vngemvotem rechen | sprach div eine nach ### nv bitet noch her hagene | ia ist iv gar ze gach ### vernemet noch div maere | wir chvmet veber sant ### dirre marcherre | der ist else genant
###### 1546 | ### sin brvoder ist geheizen | der degen gelfprat ### ein herre in beyerlande | wi mvelich ez iv stat ### welt ir dvrh sine marche | ir svlt ivh wol bewarn ### vnd svlt ovch mit dem vergen | vil bescheidenliche varn
###### 1547 | ### der ist so grimmes mvotes | er lat ivch niht genesen ### ir en welt bi dem helde | mit gvoten sinnen wesen ### welt ir daz vber er ivh fvere | so gebet im den solt ### er hvetet disses landes | vnt ist gelpfrade holt
###### 1548 | ### vnde chvom er niht bezite | so rvffet veber flvt ### vnt ieht ir heizet amelrich | der was ein helt gvt ### der dvrch fientschepfte | rvomte dizze lant ### so chvmt iv der verge | swenne im der nam wirt genant
###### 1549 | ### der vebermvte hagene | der vrowen do neich ### ern redete niht mere | wan daz er vaste sweich ### do gie er bi dem wazer | fver sich an den sant ### da er anderthalben | ein herberge vant
###### 1550 | ### er begonde vaste | rvoffen hin veber den flvt ### nv hol mich hi verge | sprach der degen gvt ### so gip ich dir ce miete | einen bovch von golde rot ### ia ist mir dirre verte | daz wizest waerliche not
###### 1551 | ### der verge was so riche | daz im niht dienen zam ### davon er lon vil selten | von iemen da genam ### ovch waren sine chnehte | vil harte hohgemvt ### noh stvnt allez hagen | eine disehalp der flvt
###### 1552 | ### do rvffte er mit der chreffte | daz al der wag erdoz ### wan des heldes sterche | was michel vnd groz ### nv hol mich amelrichen | ich pin der elsn man ### der dvrch starche fintschaft | disem lande entran
###### 1553 | ### vil hohe an dem swerte | einen bovch er im bot ### lieht vnd schoene | was er von golde rot ### daz man in veber fvrte | in gelpfrades lant ### der vebermvte verge | nam selb daz rvder an di hant
###### 1554 | ### ovch was der selb verge | nivlich gehit ### div gvf nach grozem gvte | vil boese ende git ### do wold er verdienen | daz hagenen golt so rot ### des leid er von dem degene | den swertgrimmigen tot
###### 1555 | ### der verge ilte genote | hinvber an den sant ### do zvrnde er ernslichen | als er hagenen sach ### vil harte grimmechlich | er zv dem degen sprach
###### 1556 | ### ir mvget wol sin geheizen | benamen amelrich ### des ich mich hie verwaene | dem sit ir vngelich ### von vater vnd von mvter | was er der brvder min ### nv ir mich betrogen habt | ir mvezet disehalp sin
###### 1557 | ### nein dvrch got den richen | sprach do hagene ### ich bin ein recke vremde | vnt sorge vff degene ### nv nemet hin vrivntliche | hivte minen solt ### daz ir mich vberfvret | ich pin iv waerlichen holt
###### 1558 | ### do sprach abe der verge | des mach niht gesin ### ez habent fiande | di lieben herren min ### darvmbe ich niemen vremden | fvere in diz lant ### so liebe dir si ce lebene | so trit vil balde vz an den sant
###### 1559 | ### vnt fvret vns veber tvsent ross | vnt also manigen man ### nemet von mir ce minne | diz golt vil gvt ### nv ne tvt es niht sprach hagene | wan trvrech ist min mvt ### do sprach der grimme verge | ez wirdet nimmer getan
###### 1560 | ### er hvp ein starchez rvder | michel vnd breit ### er slvch vf hagenen | des wart er vngemeit ### daz er in dem schiffe | strvchte an siniv chnie ### so rehte grimmer verge | der chom dem tronegaer nie
###### 1561 | ### do wolde er baz erzvrnen | den vbermvten gast ### er slvch im einen schalten | daz div gar cerbrast ### hagen vber daz hovbet | er was ein starcher man ### davon der elsen verge | grozen schaden da gewan
###### 1562 | ### mit grimmegem mvte | greif hagen zehant ### vil balde ze siner scheiden | da er ein waffen vant ### er slvch im ab daz hovbet | vnd varf ez an den grvnt ### div maere wurden schiere | den stolzen bvrgonden chvnt
###### 1563 | ### in den selben stvnden | do er den schifman slvch ### daz shiff daz vloz en owe | daz was im leit genvch ### e erz gerihte widere | mveden er began ### do zoh vil crefftechliche | des chvenech gventheres man
###### 1564 | ### mit zvegen harte swinden | chert ez der gast ### vnz im daz starche rvder | in der hende brast ### er wolde zv den recken | vz an einen sant ### da was deheinez mere | hey wi schier erz da gebant
###### 1565 | ### mit einem shiltvezel | daz was ein porte smal ### gegen einem walde | chert er hin ze tal ### do vant er sinen herren | an dem stade stan ### do gie im hin engegen | vil manich waetlicher man
###### 1566 | ### mit grvoze in wol enpfiengen | di snellen ritter gvt ### do sahens in dem shiffe | riechen daz blvt ### von einer starchen wunden | di er dem vergen slvch ### do wart von den degenen | gevraget hagen genvch
###### 1567 | ### do der kvenich gventher | daz heize blvt ersach ### sweben in dem shiffe | wi balde er do sprach ### wan sagt ir mir hagene | war ist der verge chomen ### iwer starchez ellen | ich waen im daz leben hat benomen
###### 1568 | ### do sprach er lovgenliche | da ich daz shif da vant ### bi den wilden widen | da lost ez min hant ### ich han deheinen vergen | hivte hie gesehen ### ez ist ovch niemen leide | von minen shvlden hi geschehen
###### 1569 | ### do sprach von bvrgonden | der herre gernot ### hivte mvz ich sorgen | vf lieber frivnde tot ### sit wir der shifflivte | bereite nine han ### wi wir chvmen veber | des mvz ich trvrende stan
###### 1570 | ### vil lvte rieff do hagene | leit nider vf daz gras ### ir chnehte div gereite | ich gedenche daz ich was ### der allerbeste verge | den man bi dem rine vant ### ia getruwe ich ivch wol bringen | hinveber in gelpfrades lant
###### 1571 | ### daz si dester balder | choemen veber flvt ### div ross si anslvgen | daz swimmen daz wart gvt ### wand in div starch vende | deheinez da benam ### etelichez owete verre | als ez mveden began
###### 1572 | ### do trvgen si cem sheffe | ir golt vnd ovh ir wat ### sit daz si der verte | niht mohten haben rat ### hagen was da meister | des fvrt er vff den sant ### vil manegen richen recken | in daz vnchvnde lant
###### 1573 | ### zem ersten braht er veber | wol tvsent ritter her ### darnach sine recken | dannoch was ir mer ### nivn tvsent knehte | fvrt er an daz lant ### des tages was vnmvezech | des tronegeres hant
###### 1574 | ### do er si wol gesvnde | brahte veber den flvt ### do gedahte vremder maere | der snelle degen gvt ### div im e da sageten | div wilden merwip ### des het des chvneges kapelan | nach verlorn sinen lip
###### 1575 | ### bi dem kappelsavme | er den pfaffen vant ### ob dem heilchtvme | er leinte an siner hant ### des moht er niht genizen | do in hagen sach ### der gotes arme priester | mvose liden vngemach
###### 1576 | ### er swang in vz dem shiffe | darzv wart im gach ### do rieffen ir genvge | nv vaha herre vach ### giselher der ivnge | zvernen erz began ### ern wold iz doh niht lazzen | ir deheinen vnderstan
###### 1577 | ### do sprach von bvrgonden | der herre gernot ### waz hilffet ivh nv hagene | des kappelanes tot ### taet ez ander iemen | daz sold iv wesen leit ### vmbe welhe shvlde | habt ir dem priester widerseit
###### 1578 | ### der pfaffe swam genote | er wolde sin genesen ### ob im iemen hvelfe | des mohte da niht wesen ### wan der starche hagene | vil zornech was gemvt ### er stiez in zv dem grvnde | daz dvhte niemene gvt
###### 1579 | ### do der arme pfaffe | der helfe nine sach ### do chert er wider vebere | des leid er vngemach ### swi er niht swimmen chvnde | im half div gotes hant ### daz er wol chom gesvnder | hin wider vz an daz lant
###### 1580 | ### do stvnt der arme priester | vnde schvtte sine wat ### dabi sach wol hagen | saz sin niht waere rat ### daz im fver war sageten | div wilden merewip ### er dahte dise degen | mvezen verliesen den lip
###### 1581 | ### do si daz shif entlvden | vnd gar getrvgen dan ### swaz darvf heten | der drier chvenege man ### hagen slvch ez ce stvchen | vnd warf ez an den flvt ### des het michel wunder | di recken chvene vnde gvt
###### 1582 | ### zwiv tvt ir daz brvder | so sprach danchwart ### wi svl wir veber | so wir di widervart ### riten von den hivnen | ze lande an den rin ### sit do sagete in hagene | daz des chvnde niht gesin
###### 1583 | ### do sprach der helt von tronege | ich tvn iz vf den wan ### ob wir an dirre reise | deheinen zagen han ### der vns entrinnen welle | dvrch zaegeliche not ### der mvz an disem waege | doch liden schameliche tot
###### 1584 | ### si fvrten mit in einen | vz bvrgonden lant ### einen helt ce sinen handen | der was volker genant ### der redete spaeheliche | allen sinen mvt ### swaz ie begie der hagene | daz dvht den videlaere gvt
###### 1585 | ### ir ross bereitet waren | di sovmer wol geladen ### si heten an der verte | noch deheinen schaden ### genomen der si mvete | wan des kveneges chappelan ### der mvse vffe sinen fvezen | hin wider zv dem rine gan

<<< Übersicht <<< vorige Seite nächste Seite >>>